NLSL: strutl2.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
strutl2.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | touppr (string, lth)
integer function | itrim (string)

## Function/Subroutine Documentation

integer function itrim | ( | character(len=*) | string | ) |

Definition at line 44 of file strutl2.f90.

subroutine touppr | ( | character(len=*) | string,
|  | integer | lth
| ) |  |

Definition at line 22 of file strutl2.f90.

Here is the caller graph for this function: